* Code for "Rising Food Prices, Food Price Volatility, and Social Unrest *
* by Marc F. Bellemare, University if Minnesota *
* American Journal of Agricultural Economics *

clear
drop _all

use "C:\BellemareAJAEFoodRiots.dta", clear

label variable counts_all "All Food-Related Social Unrest (LexisNexis)"
label variable counts_foodriot "Food Riots (LexisNexis)"
label variable factiva_counts_foodriot "Food Riots (Factiva)"
label variable factiva_counts_riot "All Food-Related Social Unrest (Factiva)"
label variable factiva_foodriot_riot "Food Riots/All Food-Related Social Unrest (Factiva)"
label variable food_r "Food Price Index"
label variable coef_var_r3 "Historical Volatility (Food, Three Months)"
label variable t "Trend"
label variable cereals_r "Cereal Price Index"
label variable maize "Maize Price Index"
label variable rice "Rice Price Index"
label variable soybeans "Soybeans Price Index"
label variable wheat "Wheat Price Index"
label variable coef_var_cereals_r3 "Historical Volatility (Cereals, Three Months)"
label variable coef_var_maize_r3 "Historical Volatility (Maize, Three Months)"
label variable coef_var_rice_r3 "Historical Volatility (Rice, Three Months)"
label variable coef_var_soybean_1_r3 "Historical Volatility (Soybeans, Three Months)"
label variable coef_var_wheat_r3 "Historical Volatility (Wheat, Three Months)"
label variable crisis_2008 "2008 Food Crisis Dummy"
label variable crisis_2010_2011 "2010-2011 Food Crisis Dummy"
label variable coef_var_r6 "Historical Volatility (Food, Six Months)"
label variable coef_var_cereals_r6 "Historical Volatility (Cereals, Six Months)"

drop *_hat


* Preliminaries: Tests *

xi: reg food_r count coef_var_r3 t i.month
predict food_rhat
dfuller food_rhat, trend

xi: reg cereals_r count coef_var_cereals_r3 t i.month
predict cereals_rhat
dfuller cereals_rhat, trend

xi: reg maize count coef_var_maize_r3 t i.month
predict maize_hat
dfuller maize_hat, trend

xi: reg rice count coef_var_rice_r3 t i.month
predict rice_hat
dfuller rice_hat, trend

xi: reg soybeans coef_var_soybean_1_r3 t i.month
predict soybeans_hat
dfuller soybeans_hat, trend

xi: reg wheat count coef_var_wheat_r3 t i.month
predict wheat_hat
dfuller wheat_hat, trend

dfuller food_rhat, trend
dfuller cereals_rhat, trend
dfuller maize_hat, trend
dfuller rice_hat, trend
dfuller soybeans_hat, trend
dfuller wheat_hat, trend

pperron food_rhat, trend
pperron cereals_rhat, trend
pperron maize_hat, trend
pperron rice_hat, trend
pperron soybeans_hat, trend
pperron wheat_hat, trend

dfgls food_rhat
dfgls cereals_rhat
dfgls maize_hat
dfgls rice_hat
dfgls soybeans_hat
dfgls wheat_hat

dfgls food_r
dfgls cereals_r
dfgls maize
dfgls rice
dfgls soybeans
dfgls wheat


dfuller food_rhat
dfuller maize_hat
dfuller rice_hat
dfuller soybeans_hat
dfuller wheat_hat

pperron food_rhat
pperron cereals_rhat
pperron maize_hat
pperron rice_hat
pperron soybeans_hat
pperron wheat_hat

dfuller food_r, trend
dfuller cereals_r, trend
dfuller maize, trend
dfuller rice, trend
dfuller soybeans, trend
dfuller wheat, trend

dfuller coef_var_r3, trend
dfuller coef_var_cereals_r3, trend
dfuller coef_var_maize_r3, trend
dfuller coef_var_rice_r3, trend
dfuller coef_var_soybean_1_r3, trend
dfuller coef_var_wheat_r3, trend

dfuller counts_all
dfuller counts_foodriot
dfuller factiva_counts_foodriot
dfuller factiva_counts_riot
dfuller factiva_foodriot_riot
dfuller atleast10_unrest


* Naive Specifications *

xi: reg counts_all food_r coef_var_r3 counts_all_1 t i.month
estat dwatson

xi: reg counts_all cereals_r coef_var_cereals_r3 counts_all_1 t i.month
estat dwatson

* t=262, k=16 means that   dL: 1.676 and dU: 1.920 *  
* There is no evidence that the error term is autocorrelated either way for food *
* since 2.021 > 1.920 and 4 - 2.021 > 1.920 *
* Likewise for cereals, since 2.005 > 1.920 and *
* 4 - 2.005 > 1.920 *

xi: reg counts_all food_r coef_var_r3 counts_all_1 t i.month
predict e, resid
gen e_lag1 = e[_n-1]
gen e_lag2 = e[_n-2]
gen e_lag3 = e[_n-3]
reg e e_lag1
reg e e_lag1 e_lag2 e_lag3
drop e e_*

xi: reg counts_all cereals_r coef_var_cereals_r3 counts_all_1 t i.month
predict e, resid
gen e_lag1 = e[_n-1]
gen e_lag2 = e[_n-2]
gen e_lag3 = e[_n-3]
reg e e_lag1
reg e e_lag1 e_lag2 e_lag3
drop e e_*


gen coef_var_r3_1 = coef_var_r3[_n-1]
reg coef_var_r3 coef_var_r3_1 t i.month
predict yhat
gen unpred_var_1 = coef_var_r3 - yhat
drop yhat

reg coef_var_r3 coef_var_r3_1
predict yhat
gen unpred_var_2 = coef_var_r3 - yhat
drop yhat

xi: reg counts_all food_r coef_var_r3 counts_all_1 t i.month
xi: reg counts_all food_r unpred_var_1 counts_all_1 t i.month
xi: reg counts_all food_r unpred_var_2 counts_all_1 t i.month

xi: ivreg counts_all coef_var_r3 counts_all_1 t i.month (food_r = count), first
xi: ivreg counts_all unpred_var_1 counts_all_1 t i.month (food_r = count), first
xi: ivreg counts_all unpred_var_2 counts_all_1 t i.month (food_r = count), first



* Figures Skipped *

* Table 1 *

sum counts_all counts_foodriot factiva_counts_foodriot factiva_foodriot_riot food_r cereals_r maize rice soybeans wheat coef_var_r3 coef_var_cereals_r3 coef_var_maize_r3 coef_var_rice_r3 coef_var_soybean_1_r3 coef_var_wheat_r3  drought earthquake epidemic extreme_temp flood insect mass_dry mass_wet storm volcano wildfire count

* Table 2 *

xi: reg counts_all food_r coef_var_r3 counts_all_1 t i.month
xi: reg counts_all cereals_r coef_var_cereals_r3 counts_all_1 t i.month


* Table 3 *

xi: ivreg counts_all coef_var_r3 counts_all_1 t i.month (food_r = count), first
xi: ivreg counts_all coef_var_cereals_r3 counts_all_1 t i.month (cereals_r = count), first

* Table 4 *

xi: ivreg counts_all coef_var_r3 crisis_2008 counts_all_1 t i.month (food_r = count), first
xi: ivreg counts_all coef_var_cereals_r3 crisis_2008 counts_all_1 t i.month (cereals_r = count), first
xi: ivreg counts_all coef_var_r3 crisis_2010_2011 counts_all_1 t i.month (food_r = count), first
xi: ivreg counts_all coef_var_cereals_r3 crisis_2010_2011 counts_all_1 t i.month (cereals_r = count), first


* Table 5 *

xi: ivreg counts_all counts_all_1 t i.month (food_r = count), first
xi: ivreg counts_all counts_all_1 t i.month (cereals_r = count), first


* Table 6 *

xi: reg counts_all coef_var_r3 counts_all_1 t i.month
xi: reg counts_all coef_var_cereals_r3 counts_all_1 t i.month



* Appendix *

* Figures Skipped *

* Table A1 *

xi: reg counts_all count

* Table A2 *

gen count_alt1 = drought + extreme_temp + flood + insect
xi: ivreg counts_all coef_var_r3 counts_all_1 t i.month (food_r =count_alt1), first
xi: ivreg counts_all coef_var_cereals_r3 counts_all_1 t i.month (cereals_r =count_alt1), first

gen count_alt2 = drought + extreme_temp + flood
xi: ivreg counts_all coef_var_r3 counts_all_1 t i.month (food_r =count_alt2), first
xi: ivreg counts_all coef_var_cereals_r3 counts_all_1 t i.month (cereals_r =count_alt2), first

* Table A3 *

xi: reg counts_all food_r coef_var_r3 food_r_lead1 food_r_lead2 food_r_lead3 food_r_lag1 food_r_lag2 food_r_lag3 counts_all_1 t i.month
xi: reg counts_all cereals_r coef_var_cereals_r3 cereals_r_lead1 cereals_r_lead2 cereals_r_lead3 cereals_r_lag1 cereals_r_lag2 cereals_r_lag3 counts_all_1 t i.month

* Table A4 *

xi: reg counts_all food_r coef_var_r6 counts_all_1 t i.month
xi: reg counts_all cereals_r coef_var_cereals_r6 counts_all_1 t i.month
xi: ivreg counts_all coef_var_r6 counts_all_1 t i.month (food_r = count), first
xi: ivreg counts_all coef_var_cereals_r6 counts_all_1 t i.month (cereals_r = count), first

* Table A5 *

xi: reg counts_all maize coef_var_maize_r3 counts_all_1 t i.month
xi: reg counts_all rice coef_var_rice_r3 counts_all_1 t i.month
xi: reg counts_all soybeans coef_var_soybean_1_r3 counts_all_1 t i.month
xi: reg counts_all wheat coef_var_wheat_r3 counts_all_1 t i.month

* Table A6 *

xi: ivreg counts_all coef_var_maize_r3 counts_all_1 t i.month (maize = count), first
xi: ivreg counts_all coef_var_rice_r3 counts_all_1 t i.month (rice = count), first
xi: ivreg counts_all coef_var_soybean_2_r3 counts_all_1 t i.month (soybean_2 = count), first
xi: ivreg counts_all coef_var_wheat_r3 counts_all_1 t i.month (wheat = count), first

* Table A7 *

xi: poisson counts_all food_r coef_var_r3 counts_all_1 t i.month
xi: poisson counts_all cereals_r coef_var_cereals_r3 counts_all_1 t i.month
xi: poisson counts_all maize coef_var_maize_r3 counts_foodriot_1 t i.month
xi: poisson counts_all rice coef_var_rice_r3 counts_foodriot_1 t i.month
xi: poisson counts_all soybean_2 coef_var_soybean_2_r3 counts_foodriot_1 t i.month
xi: poisson counts_all wheat coef_var_wheat_r3 counts_foodriot_1 t i.month

* Table A8 *

xi: reg counts_foodriot food_r coef_var_r3 counts_foodriot_1 t i.month
xi: reg counts_foodriot cereals_r coef_var_cereals_r3 counts_foodriot_1 t i.month
xi: ivreg counts_foodriot coef_var_r3 counts_foodriot_1 t i.month (food_r = count), first
xi: ivreg counts_foodriot coef_var_cereals_r3 counts_foodriot_1 t i.month (cereals_r = count), first

* Table A9 *

xi: reg factiva_counts_foodriot food_r coef_var_r3 factiva_counts_foodriot_1 t i.month
xi: reg factiva_counts_foodriot cereals_r coef_var_cereals_r3 factiva_counts_foodriot_1 t i.month
xi: ivreg factiva_counts_foodriot coef_var_r3 factiva_counts_foodriot_1 t i.month (food_r = count), first
xi: ivreg factiva_counts_foodriot coef_var_cereals_r3 factiva_counts_foodriot_1 t i.month (cereals_r = count), first


* Table A10 *

xi: reg factiva_foodriot_riot food_r coef_var_r3 factiva_foodriot_riot_1 t i.month
xi: reg factiva_foodriot_riot cereals_r coef_var_cereals_r3 factiva_foodriot_riot_1 t i.month
xi: ivreg factiva_foodriot_riot coef_var_r3 factiva_foodriot_riot_1 t i.month (food_r = count), first
xi: ivreg factiva_foodriot_riot coef_var_cereals_r3 factiva_foodriot_riot_1 t i.month (cereals_r = count), first

* Table A11 *

drop volatility*r3 volatility*r6

drop mean_r3 a_r3
gen mean_r3 = (food_r[_n] + food_r[_n+1] + food_r[_n+2])/3
gen a_r3 = 1/3*((food_r[_n]-mean_r3)^2 + (food_r[_n+1]-mean_r3)^2 + (food_r[_n+2]-mean_r3)^2)
gen volatility_r3 = sqrt(a_r3)
gen coef_var_imp_r3 = volatility_r3/mean_r3

drop mean_r6 a_r6 
gen mean_r6 = (food_r[_n] + food_r[_n+1] + food_r[_n+2] + food_r[_n+3] + food_r[_n+4] + food_r[_n+5])/6
gen a_r6 = 1/6*((food_r[_n]-mean_r6)^2 + (food_r[_n+1]-mean_r6)^2 + (food_r[_n+2]-mean_r6)^2 + (food_r[_n+3]-mean_r6)^2 + (food_r[_n+4]-mean_r6)^2 + (food_r[_n+5]-mean_r6)^2)
gen volatility_r6 = sqrt(a_r6)
gen coef_var_imp_r6 = volatility_r6/mean_r6

drop mean_r6 a_r6
gen mean_r6 = (cereals_r[_n] + cereals_r[_n+1] + cereals_r[_n+2] + cereals_r[_n+3] + cereals_r[_n+4] + cereals_r[_n+5])/6
gen a_r6 = 1/6*((cereals_r[_n]-mean_r6)^2 + (cereals_r[_n+1]-mean_r6)^2 + (cereals_r[_n+2]-mean_r6)^2 + (cereals_r[_n+3]-mean_r6)^2 + (cereals_r[_n+4]-mean_r6)^2 + (cereals_r[_n+5]-mean_r6)^2)
gen volatility_cereals_r6 = sqrt(a_r6)
gen coef_var_imp_cereals_r6 = volatility_cereals_r6/mean_r6

drop mean_r3 a_r3
gen mean_r3 = (cereals_r[_n] + cereals_r[_n+1] + cereals_r[_n+2])/3
gen a_r3 = 1/3*((cereals_r[_n]-mean_r3)^2 + (cereals_r[_n+1]-mean_r3)^2 + (cereals_r[_n+2]-mean_r3)^2)
gen volatility_cereals_r3 = sqrt(a_r3)
gen coef_var_imp_cereals_r3 = volatility_cereals_r3/mean_r3

drop mean_r3 a_r3
gen mean_r3 = (maize[_n] + maize[_n+1] + maize[_n+2])/3
gen a_r3 = 1/3*((maize[_n]-mean_r3)^2 + (maize[_n+1]-mean_r3)^2 + (maize[_n+2]-mean_r3)^2)
gen volatility_maize_r3 = sqrt(a_r3)
gen coef_var_imp_maize_r3 = volatility_maize_r3/mean_r3

drop mean_r3 a_r3
gen mean_r3 = (rice[_n] + rice[_n+1] + rice[_n+2])/3
gen a_r3 = 1/3*((rice[_n]-mean_r3)^2 + (rice[_n+1]-mean_r3)^2 + (rice[_n+2]-mean_r3)^2)
gen volatility_rice_r3 = sqrt(a_r3)
gen coef_var_imp_rice_r3 = volatility_rice_r3/mean_r3

drop mean_r3 a_r3
gen mean_r3 = (soybeans[_n] + soybeans[_n+1] + soybeans[_n+2])/3
gen a_r3 = 1/3*((soybeans[_n]-mean_r3)^2 + (soybeans[_n+1]-mean_r3)^2 + (soybeans[_n+2]-mean_r3)^2)
gen volatility_soybean_1_r3 = sqrt(a_r3)
gen coef_var_imp_soybean_1_r3 = volatility_soybean_1_r3/mean_r3

drop mean_r3 a_r3
gen mean_r3 = (soybean_2[_n] + soybean_2[_n+1] + soybean_2[_n+2])/3
gen a_r3 = 1/3*((soybean_2[_n]-mean_r3)^2 + (soybean_2[_n+1]-mean_r3)^2 + (soybean_2[_n+2]-mean_r3)^2)
gen volatility_soybean_2_r3 = sqrt(a_r3)
gen coef_var_imp_soybean_2_r3 = volatility_soybean_2_r3/mean_r3

drop mean_r3 a_r3
gen mean_r3 = (wheat[_n] + wheat[_n+1] + wheat[_n+2])/3
gen a_r3 = 1/3*((wheat[_n]-mean_r3)^2 + (wheat[_n+1]-mean_r3)^2 + (wheat[_n+2]-mean_r3)^2)
gen volatility_wheat_r3 = sqrt(a_r3)
gen coef_var_imp_wheat_r3 = volatility_wheat_r3/mean_r3

label variable coef_var_imp_r3 "Implied Volatility (Food, Three Months)"
label variable coef_var_imp_cereals_r3 "Implied Volatility (Cereals, Three Months)"
label variable coef_var_imp_maize_r3 "Implied Volatility (Maize, Three Months)"
label variable coef_var_imp_rice_r3 "Implied Volatility (Rice, Three Months)"
label variable coef_var_imp_soybean_1_r3 "Implied Volatility (Soybeans, Three Months)"
label variable coef_var_imp_wheat_r3 "Implied Volatility (Wheat, Three Months)"

xi: ivreg counts_all coef_var_imp_r3 counts_all_1 t i.month (food_r = count), first
xi: ivreg counts_all coef_var_imp_cereals_r3 counts_all_1 t i.month (cereals_r = count), first
xi: ivreg counts_all coef_var_imp_maize_r3 counts_all_1 t i.month (maize = count), first
xi: ivreg counts_all coef_var_imp_rice_r3 counts_all_1 t i.month (rice = count), first
xi: ivreg counts_all coef_var_imp_soybean_2_r3 counts_all_1 t i.month (soybean_2 = count), first
xi: ivreg counts_all coef_var_imp_wheat_r3 counts_all_1 t i.month (wheat = count), first

* Tables A12 and A13 Skipped - SCAD Data Required; Available from Cullen Hendrix and Idean Salehyan *

* Figures Skipped *


